@@ -392,7 +392,7 @@ class Data:
     # Calculate плюс версия калкулэйта для записи в заголовок файла
     # объединяемого с профилем
     #setup_name
-    cl_ver = {'value':'Calculate-server 2.0.6'}
+    cl_ver = {'value':'Calculate-server 2.0.7'}
 
     #DN LDAP ветки, в котором будут находится служебные ветки
     ld_ldap_dn = {}
@@ -416,5 +416,20 @@ class Data:
     ld_repl_worked_dn = {}
     #имя ветки 
     ld_repl_worked_login = {'value':'Worked'}
-    #DN ветки хранения аттрибутов доступа пользователя
-    ld_repl_access_dn = {}
+
+    # Текст в slapd.conf, в котором находится информация о серверах репликации
+    ld_repl_servers_info = {}
+    # Текст в slapd.conf, ссылки на серверы репликации
+    ld_repl_servers_ref = {}
+    # id текущего сервера репликации
+    ld_repl_id = {}
+    # Доменные имена серверов репликации для веток Unix, Samba
+    ld_repl_samba_servers = {}
+    # Доменные имена серверов репликации для ветки Unix
+    ld_repl_unix_servers = {}
+    # Доменные имена серверов репликации
+    ld_repl_servers = {}
+    # id серверов репликации
+    ld_repl_ids = {}
+    # Включена или нет репликация для сервиса Samba
+    ld_repl_samba_set = {}
\ No newline at end of file
